pub enum Error {
TemplateError {
msg: String,
cause: Box<Error>,
},
PageDirectionError(String),
InvalidMetadataError(String),
IoError {
msg: String,
cause: Error,
},
ZipCommandError(String),
ZipError(ZipError),
ZipErrorWithMessage {
msg: String,
cause: ZipError,
},
InvalidPath(String),
}Expand description
Error type of this crate. Each variant represent a type of event that may happen during this crate’s operations.
Variants
TemplateError
An error caused while processing a template or its rendering.
Fields
PageDirectionError(String)
An error returned when encountering an unknown PageDirection.
InvalidMetadataError(String)
An error returned when an unknown metadata key has been encountered.
IoError
An error returned when attempting to access the filesystem
Fields
ZipCommandError(String)
An error returned when something happened while invoking a zip program. See ZipCommand.
ZipError(ZipError)
An error returned when the zip library itself returned an error. See ZipLibrary.
ZipErrorWithMessage
An error returned when the zip library itself returned an error, but with an additional message. See ZipLibrary.
Fields
InvalidPath(String)
An error returned when an invalid [Path] has been encountered during epub processing.